@@ -1,6 +1,7 @@
 ;;;Auto generated
 
-;;;### (autoloads (g-auth-lifetime) "g-auth" "g-auth.el" (20379 9383))
+;;;### (autoloads (g-auth-lifetime) "g-auth" "g-auth.el" (20770 54728
+;;;;;;  0 0))
 ;;; Generated autoloads from g-auth.el
 
 (defvar g-auth-lifetime "4 hours" "\
@@ -13,7 +14,7 @@ Auth lifetime.")
 ;;;### (autoloads (gblogger-sign-in gblogger-sign-out gblogger-add-label
 ;;;;;;  gblogger-delete-entry gblogger-new-entry gblogger-edit-entry
 ;;;;;;  gblogger-atom-display gblogger-blog) "gblogger" "gblogger.el"
-;;;;;;  (20328 48785))
+;;;;;;  (20770 54728 0 0))
 ;;; Generated autoloads from gblogger.el
 
 (autoload 'gblogger-blog "gblogger" "\
@@ -61,7 +62,7 @@ Resets client so you can start with a different userid.
 ;;;***
 
 ;;;### (autoloads (gbooks-sign-in gbooks-sign-out) "gbooks" "gbooks.el"
-;;;;;;  (20336 46200))
+;;;;;;  (20770 54728 0 0))
 ;;; Generated autoloads from gbooks.el
 
 (autoload 'gbooks-sign-out "gbooks" "\
@@ -79,7 +80,8 @@ Resets client so you can start with a different userid.
 ;;;### (autoloads (gcal-sign-in gcal-sign-out gcal-emacs-calendar-setup
 ;;;;;;  gcal-show-event gcal-view gcal-calendar-agenda-days gcal-reject-event
 ;;;;;;  gcal-delete-event gcal-quickadd-event gcal-add-event gcal-user-email
-;;;;;;  gcal-default-user-email) "gcal" "gcal.el" (20328 48785))
+;;;;;;  gcal-default-user-email) "gcal" "gcal.el" (20770 54728 0
+;;;;;;  0))
 ;;; Generated autoloads from gcal.el
 
 (defvar gcal-default-user-email nil "\
@@ -148,7 +150,7 @@ Sign in, useful when changing to a different user profile.
 ;;;***
 
 ;;;### (autoloads (gcontacts-create gcontacts-initialize) "gcontacts"
-;;;;;;  "gcontacts.el" (20328 48785))
+;;;;;;  "gcontacts.el" (20770 54728 0 0))
 ;;; Generated autoloads from gcontacts.el
 
 (autoload 'gcontacts-initialize "gcontacts" "\
@@ -164,8 +166,8 @@ Create a new contact as specified.
 ;;;***
 
 ;;;### (autoloads (gdocs-sign-in gdocs-sign-out gdocs-view-item gdocs-delete-item
-;;;;;;  gdocs-add-collaborator gdocs-doclist) "gdocs" "gdocs.el"
-;;;;;;  (20328 48785))
+;;;;;;  gdocs-add-collaborator gdocs-publish gdocs-doclist) "gdocs"
+;;;;;;  "gdocs.el" (20770 54728 0 0))
 ;;; Generated autoloads from gdocs.el
 
 (autoload 'gdocs-doclist "gdocs" "\
@@ -174,6 +176,11 @@ Interactive prefix arg prompts for a query string.
 
 \(fn &optional QUERY)" t nil)
 
+(autoload 'gdocs-publish "gdocs" "\
+Export from given content type to Google Docs.
+
+\(fn CONTENT-TYPE)" t nil)
+
 (autoload 'gdocs-add-collaborator "gdocs" "\
 Add collaborator to ACL at acl-url.
 You can find the acl-url through the DocList.
@@ -203,7 +210,7 @@ Resets client so you can start with a different userid.
 ;;;***
 
 ;;;### (autoloads (gfeeds-lookup-and-view gfeeds-view gfeeds-titles
-;;;;;;  gfeeds-freshness) "gfeeds" "gfeeds.el" (20328 48785))
+;;;;;;  gfeeds-freshness) "gfeeds" "gfeeds.el" (20770 54728 0 0))
 ;;; Generated autoloads from gfeeds.el
 
 (defsubst gfeeds-feed (feed-url) "\
@@ -239,7 +246,8 @@ Lookup feed URL for a site and browse result.
 ;;;***
 
 ;;;### (autoloads (gfinance-sign-in gfinance-sign-out gfinance-display-feed
-;;;;;;  gfinance-portfolios) "gfinance" "gfinance.el" (20328 48785))
+;;;;;;  gfinance-portfolios) "gfinance" "gfinance.el" (20770 54728
+;;;;;;  0 0))
 ;;; Generated autoloads from gfinance.el
 
 (autoload 'gfinance-portfolios "gfinance" "\
@@ -265,7 +273,7 @@ Resets client so you can start with a different userid.
 ;;;***
 
 ;;;### (autoloads (ghealth-sign-in ghealth-sign-out) "ghealth" "ghealth.el"
-;;;;;;  (20328 48785))
+;;;;;;  (20770 54728 0 0))
 ;;; Generated autoloads from ghealth.el
 
 (autoload 'ghealth-sign-out "ghealth" "\
@@ -278,6 +286,37 @@ Resets client so you can start with a different userid.
 
 \(fn)" t nil)
 
+;;;***
+
+;;;### (autoloads (gmaps gweb-my-address gmaps-reverse-geocode gmaps-geocode)
+;;;;;;  "gmaps" "gmaps.el" (20878 39005 0 0))
+;;; Generated autoloads from gmaps.el
+
+(autoload 'gmaps-geocode "gmaps" "\
+Geocode given address.
+Optional argument `raw-p' returns complete JSON  object.
+
+\(fn ADDRESS &optional RAW-P)" nil nil)
+
+(autoload 'gmaps-reverse-geocode "gmaps" "\
+Reverse geocode lat-long.
+Optional argument `raw-p' returns raw JSON  object.
+
+\(fn LAT-LONG &optional RAW-P)" nil nil)
+
+(defvar gweb-my-location nil "\
+Geo coordinates --- automatically set by reverse geocoding gweb-my-address")
+
+(defvar gweb-my-address nil "\
+Location address. Setting this updates gweb-my-location coordinates  via geocoding.")
+
+(custom-autoload 'gweb-my-address "gmaps" nil)
+
+(autoload 'gmaps "gmaps" "\
+Google Maps Interaction.
+
+\(fn)" t nil)
+
 ;;;***
 
 ;;;### (autoloads (gphoto-edit-entry gphoto-sign-in gphoto-sign-out
@@ -285,7 +324,7 @@ Resets client so you can start with a different userid.
 ;;;;;;  gphoto-album-create gphoto-user-tagsearch gphoto-user-search
 ;;;;;;  gphoto-recent gphoto-community-search gphoto-download gphoto-view
 ;;;;;;  gphoto-tags gphoto-albums gphoto-feeds) "gphoto" "gphoto.el"
-;;;;;;  (20328 48785))
+;;;;;;  (20770 54728 0 0))
 ;;; Generated autoloads from gphoto.el
 
 (autoload 'gphoto-feeds "gphoto" "\
@@ -379,7 +418,7 @@ The retrieved entry is placed in a buffer ready for editing.
 ;;;;;;  greader-title-feed greader-unsubscribe-feed greader-subscribe-feed
 ;;;;;;  greader-opml greader-feed-list greader-subscriptions greader-subscription-list
 ;;;;;;  greader-preferences greader-reading-list) "greader" "greader.el"
-;;;;;;  (20328 48784))
+;;;;;;  (20770 54728 0 0))
 ;;; Generated autoloads from greader.el
 
 (autoload 'greader-reading-list "greader" "\
@@ -484,7 +523,7 @@ Reauthenticate current user.
 ;;;***
 
 ;;;### (autoloads (gsheet-sign-in gsheet-sign-out gsheet-sheets gsheet-fetch)
-;;;;;;  "gsheet" "gsheet.el" (20328 48785))
+;;;;;;  "gsheet" "gsheet.el" (20770 54728 0 0))
 ;;; Generated autoloads from gsheet.el
 
 (autoload 'gsheet-fetch "gsheet" "\
@@ -510,7 +549,7 @@ Resets client so you can start with a different userid.
 ;;;***
 
 ;;;### (autoloads (gskeleton-sign-in gskeleton-sign-out) "gskeleton"
-;;;;;;  "gskeleton.el" (20328 48784))
+;;;;;;  "gskeleton.el" (20770 54728 0 0))
 ;;; Generated autoloads from gskeleton.el
 
 (autoload 'gskeleton-sign-out "gskeleton" "\
@@ -528,7 +567,7 @@ Resets client so you can start with a different userid.
 ;;;### (autoloads (gtube-video-featured gtube-video-by-user gtube-video-popular
 ;;;;;;  gtube-video-playlist gtube-video-by-category-and-tag gtube-video-by-tag
 ;;;;;;  gtube-video-details gtube-user-friends gtube-user-favorites
-;;;;;;  gtube-user-profile) "gtube" "gtube.el" (20328 48785))
+;;;;;;  gtube-user-profile) "gtube" "gtube.el" (20770 54728 0 0))
 ;;; Generated autoloads from gtube.el
 
 (autoload 'gtube-user-profile "gtube" "\
@@ -592,8 +631,8 @@ Retrieved featured video list.
 
 ;;;***
 
-;;;### (autoloads (gweb-my-address gweb-maps-reverse-geocode gweb-maps-geocode
-;;;;;;  gweb-google-at-point) "gweb" "gweb.el" (20328 48785))
+;;;### (autoloads (gweb-google-at-point) "gweb" "gweb.el" (20770
+;;;;;;  55132 0 0))
 ;;; Generated autoloads from gweb.el
 
 (defsubst gweb-google-autocomplete-with-corpus (corpus) "\
@@ -607,36 +646,16 @@ Optional interactive prefix arg refresh forces this cached URL to be refreshed.
 
 \(fn SEARCH-TERM &optional REFRESH)" t nil)
 
-(autoload 'gweb-maps-geocode "gweb" "\
-Geocode given address.
-Optional argument `raw-p' returns complete JSON  object.
-
-\(fn ADDRESS &optional RAW-P)" nil nil)
-
-(autoload 'gweb-maps-reverse-geocode "gweb" "\
-Reverse geocode lat-long.
-Optional argument `raw-p' returns raw JSON  object.
-
-\(fn LAT-LONG &optional RAW-P)" nil nil)
-
-(defvar gweb-my-location nil "\
-Geo coordinates --- automatically set by reverse geocoding gweb-my-address")
-
-(defvar gweb-my-address nil "\
-Location address. Setting this updates gweb-my-location coordinates  via geocoding.")
-
-(custom-autoload 'gweb-my-address "gweb" nil)
-
 ;;;***
 
 ;;;### (autoloads nil nil ("g-autogen.el" "g-cus-load.el" "g-load-path.el"
 ;;;;;;  "g-utils.el" "g.el" "gnotebook.el" "gwis.el" "indent-files.el"
-;;;;;;  "org2blogger.el") (20556 53607 726674))
+;;;;;;  "org2blogger.el") (21040 11011 496839 0))
 
 ;;;***
 
-;;;### (autoloads (g-app-view g-app-publish) "g-app" "g-app.el" (20328
-;;;;;;  48785))
+;;;### (autoloads (g-app-view g-app-publish) "g-app" "g-app.el" (20770
+;;;;;;  54728 0 0))
 ;;; Generated autoloads from g-app.el
 
 (autoload 'g-app-publish "g-app" "\
